@@ -3,7 +3,7 @@
 =head1 NAME
 
 Catalyst::Plugin::Authentication::Store::LDAP::User
- - A User object representing an LDAP object. 
+ - A User object representing an LDAP object **DEPRECATED**
 
 =head1 SYNOPSIS
 
@@ -21,6 +21,8 @@ username.
 
 =head1 DESCRIPTION
 
+B<This module is deprecated. Please use L<Catalyst::Authentication::Store::LDAP> instead.>
+
 This wraps up an LDAP object and presents a simplified interface to it's
 contents.  It uses some AUTOLOAD magic to pass method calls it doesn't
 understand through as simple read only accessors for the LDAP entries
@@ -45,7 +47,7 @@ use base qw/Catalyst::Plugin::Authentication::User Class::Accessor::Fast/;
 use strict;
 use warnings;
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 BEGIN { __PACKAGE__->mk_accessors(qw/user store/) }
 
